@@ -20,6 +20,7 @@
 """Client functionality."""
 
 import json
+import math
 import time
 from dataclasses import dataclass
 from datetime import datetime, timedelta
@@ -38,6 +39,7 @@ from cosmpy.aerial.client.staking import (
 )
 from cosmpy.aerial.client.utils import (
     ensure_timedelta,
+    get_paginated,
     prepare_and_broadcast_basic_transaction,
 )
 from cosmpy.aerial.config import NetworkConfig
@@ -171,11 +173,20 @@ class StakingSummary:
 class LedgerClient:
     """Ledger client."""
 
-    def __init__(self, cfg: NetworkConfig):
+    def __init__(
+        self,
+        cfg: NetworkConfig,
+        query_interval_secs: int = DEFAULT_QUERY_INTERVAL_SECS,
+        query_timeout_secs: int = DEFAULT_QUERY_TIMEOUT_SECS,
+    ):
         """Init ledger client.
 
         :param cfg: Network configurations
+        :param query_interval_secs: int. optional interval int seconds
+        :param query_timeout_secs: int. optional interval int seconds
         """
+        self._query_interval_secs = query_interval_secs
+        self._query_timeout_secs = query_timeout_secs
         cfg.validate()
         self._network_config = cfg
         self._gas_strategy: GasStrategy = SimulationGasStrategy(self)
@@ -366,42 +377,46 @@ class LedgerClient:
         current_positions: List[StakingPosition] = []
 
         req = QueryDelegatorDelegationsRequest(delegator_addr=str(address))
-        resp = self.staking.DelegatorDelegations(req)
 
-        for item in resp.delegation_responses:
+        for resp in get_paginated(
+            req, self.staking.DelegatorDelegations, per_page_limit=1
+        ):
+            for item in resp.delegation_responses:
 
-            req = QueryDelegationRewardsRequest(
-                delegator_address=str(address),
-                validator_address=str(item.delegation.validator_address),
-            )
-            rewards_resp = self.distribution.DelegationRewards(req)
-
-            stake_reward = 0
-            for reward in rewards_resp.rewards:
-                if reward.denom == self.network_config.staking_denomination:
-                    stake_reward = int(reward.amount) // COSMOS_SDK_DEC_COIN_PRECISION
-                    break
-
-            current_positions.append(
-                StakingPosition(
-                    validator=Address(item.delegation.validator_address),
-                    amount=int(item.balance.amount),
-                    reward=stake_reward,
+                req = QueryDelegationRewardsRequest(
+                    delegator_address=str(address),
+                    validator_address=str(item.delegation.validator_address),
                 )
-            )
+                rewards_resp = self.distribution.DelegationRewards(req)
 
-        req = QueryDelegatorUnbondingDelegationsRequest(delegator_addr=str(address))
-        resp = self.staking.DelegatorUnbondingDelegations(req)
+                stake_reward = 0
+                for reward in rewards_resp.rewards:
+                    if reward.denom == self.network_config.staking_denomination:
+                        stake_reward = (
+                            int(reward.amount) // COSMOS_SDK_DEC_COIN_PRECISION
+                        )
+                        break
+
+                current_positions.append(
+                    StakingPosition(
+                        validator=Address(item.delegation.validator_address),
+                        amount=int(item.balance.amount),
+                        reward=stake_reward,
+                    )
+                )
 
         unbonding_summary: Dict[str, int] = {}
-        for item in resp.unbonding_responses:
-            validator = str(item.validator_address)
-            total_unbonding = unbonding_summary.get(validator, 0)
+        req = QueryDelegatorUnbondingDelegationsRequest(delegator_addr=str(address))
 
-            for entry in item.entries:
-                total_unbonding += int(entry.balance)
+        for resp in get_paginated(req, self.staking.DelegatorUnbondingDelegations):
+            for item in resp.unbonding_responses:
+                validator = str(item.validator_address)
+                total_unbonding = unbonding_summary.get(validator, 0)
 
-            unbonding_summary[validator] = total_unbonding
+                for entry in item.entries:
+                    total_unbonding += int(entry.balance)
+
+                unbonding_summary[validator] = total_unbonding
 
         # build the final list of unbonding positions
         unbonding_positions: List[UnbondingPositions] = []
@@ -549,7 +564,8 @@ class LedgerClient:
         :param gas_limit: gas limit
         :return: Estimated fee for transaction
         """
-        return f"{gas_limit * self.network_config.fee_minimum_gas_price}{self.network_config.fee_denomination}"
+        fee = math.ceil(gas_limit * self.network_config.fee_minimum_gas_price)
+        return f"{fee}{self.network_config.fee_denomination}"
 
     def estimate_gas_and_fee_for_tx(self, tx: Transaction) -> Tuple[int, str]:
         """Estimate gas and fee for transaction.
@@ -580,12 +596,12 @@ class LedgerClient:
         timeout = (
             ensure_timedelta(timeout)
             if timeout
-            else timedelta(seconds=DEFAULT_QUERY_TIMEOUT_SECS)
+            else timedelta(seconds=self._query_timeout_secs)
         )
         poll_period = (
             ensure_timedelta(poll_period)
             if poll_period
-            else timedelta(seconds=DEFAULT_QUERY_INTERVAL_SECS)
+            else timedelta(seconds=self._query_interval_secs)
         )
 
         start = datetime.now()
